# qibojit

![Tests](https://github.com/qiboteam/qibojit/workflows/Tests/badge.svg)
[![codecov](https://codecov.io/gh/qiboteam/qibojit/branch/main/graph/badge.svg?token=580GFLLFNN)](https://codecov.io/gh/qiboteam/qibojit)
[![DOI](https://zenodo.org/badge/360678684.svg)](https://zenodo.org/badge/latestdoi/360678684)

This package provides acceleration features for [Qibo](https://github.com/qiboteam/qibo) simulations using just-in-time (JIT) custom kernel with [numba](https://numba.pydata.org/) and [cupy](https://cupy.dev/).

## Documentation

The qibojit backend documentation is available at [qibo.readthedocs.io](https://qibo.readthedocs.io/en/stable/installation.html).

## Citation policy

If you use the package please cite the following references:
- https://arxiv.org/abs/2009.01845
- https://doi.org/10.5281/zenodo.3997194
- https://doi.org/10.5281/zenodo.5071354
